@@ -8,13 +8,13 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-08-20'; # DATE
 our $DIST = 'App-imgsize'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our @EXPORT_OK = qw(imgsize);
 
 our %SPEC;
 
-my $res_meta = {'table.fields' => [qw/filename filesize width height res_name/]};
+our $res_meta = {'table.fields' => [qw/filename filesize width height res_name/]};
 
 $SPEC{imgsize} = {
     v => 1.1,
@@ -26,19 +26,19 @@ $SPEC{imgsize} = {
             schema => ['array*' => {of => 'filename*'}],
             req => 1,
             pos => 0,
-            greedy => 1,
+            slurpy => 1,
         },
         detail => {
             summary => 'Whether to show detailed records',
             schema => 'bool*',
-            description => <<'_',
+            description => <<'MARKDOWN',
 
 The default is to show detailed records when there are more than 1 filenames
 specified; when there is only 1 filename, will only show dimension in WxH format
 (e.g. 640x480). If this option is specified, will show detailed records even if
 there is only one filename specified.
 
-_
+MARKDOWN
             cmdline_aliases => {l=>{}},
         },
     },
@@ -122,7 +122,7 @@ App::imgsize - Show dimensions of image files
 
 =head1 VERSION
 
-This document describes version 0.005 of App::imgsize (from Perl distribution App-imgsize), released on 2024-08-20.
+This document describes version 0.006 of App::imgsize (from Perl distribution App-imgsize), released on 2024-08-20.
 
 =head1 SYNOPSIS
 
